@@ -9,8 +9,6 @@ import pandas as pd
 import numpy as np
 import sys
 
-import nltk
-nltk.download('stopwords')
 
 
 def cappuccino(text: str,                  # Text
@@ -25,7 +23,6 @@ def cappuccino(text: str,                  # Text
                numbers: bool = False,      # Remove numbers
                lower_case: bool = False):  # Lowercase text before cleaning and frequency analysis
 
-
     result = arabica_freq(text = text,
                           time = time,
                           date_format = date_format,
@@ -94,7 +91,7 @@ def cappuccino(text: str,                  # Text
                 reshaped_unigram = reshaped_unigram[['unigram', 'frequency', 'period','label']]
 
                 fig = (ggplot(reshaped_unigram, aes('period', 'unigram', fill='frequency'))
-                       + geom_tile(aes(width=.95, height=.95))
+                       + geom_tile(aes(width=1, height=1))
                        + geom_text(aes(label='frequency'), size=10)
                        + theme_minimal()
                        + scale_fill_gradient(name = "frequency",
@@ -102,14 +99,15 @@ def cappuccino(text: str,                  # Text
                                              high = "#496160")
                        + theme(axis_title_x=element_text(colour = "black"),
                                axis_title_y=element_text(colour="black"),
-                               axis_text_x=element_text(colour = "black", rotation=45, hjust=1),
-                               figure_size=(10, 5),
+                               axis_text_x=element_text(colour = "black", rotation=45, hjust= 1),
+                               legend_text = element_text(size = 7),
+                               legend_title = element_text(color = "black", vjust= -1.3, size = 10),
+                               figure_size= (3 + ((len(period) /4)), (3 + (max_words * 1.5))),
                                panel_grid_major = element_line(color='black',size = 0.1),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
                        ).draw(show=False, return_ggplot=True)
 
-
                 plt.gcf().set_dpi(800)
                 picture = plt.show()
 
@@ -189,19 +187,21 @@ def cappuccino(text: str,                  # Text
                 reshaped_unigram = reshaped_unigram[['unigram', 'frequency', 'period','label']]
 
                 fig = (ggplot(reshaped_unigram, aes('period', 'unigram', fill='frequency'))
-                       + geom_tile(aes(width=.95, height=.95))
+                       + geom_tile(aes(width=0.95, height=0.95))
                        + geom_text(aes(label='frequency'), size=10)
                        + theme_minimal()
-                       + scale_fill_gradient(name = "frequency",
-                                             low = "#f0f4ed",
-                                             high = "#496160")
                        + theme(axis_title_x=element_text(colour = "black"),
                                axis_title_y=element_text(colour="black"),
-                               axis_text_x=element_text(colour = "black", rotation=45, hjust='1'),
-                               figure_size=(10, 6),
+                               axis_text_x=element_text(colour = "black", rotation=45, hjust= 1),
+                               legend_text = element_text(size = 7),
+                               legend_title = element_text(color = "black", size = 10),
+                               figure_size= (3 + ((len(period) /4)), (2 + (max_words * 0.5))),
                                panel_grid_major = element_line(color='black',size = 0.1),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
+                       + scale_fill_gradient(name = "frequency",
+                                             low = "#f0f4ed",
+                                             high = "#496160")
                        ).draw(show=False, return_ggplot=True)
 
                 plt.gcf().set_dpi(800)
@@ -234,7 +234,7 @@ def cappuccino(text: str,                  # Text
                                legend_title = element_text(size=10),
                                legend_key_height = 0.5,
                                legend_key_width = 0.5,
-                               figure_size=(10, 5),
+                               figure_size=(5 + max_words, (1 + (max_words * 1.0))),
                                panel_grid_major = element_blank(),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
@@ -315,8 +315,10 @@ def cappuccino(text: str,                  # Text
                                              high = "#496160")
                        + theme(axis_title_x=element_text(colour = "black"),
                                axis_title_y=element_text(colour="black"),
-                               axis_text_x=element_text(colour = "black", rotation=45, hjust=1),
-                               figure_size=(10, 8),
+                               axis_text_x=element_text(colour = "black", rotation=45, hjust= 1),
+                               legend_text = element_text(size = 5,vjust = 0.2),
+                               legend_title = element_text(color = "black", vjust = 0.8, size = 10),
+                               figure_size= (3 + ((len(period) /4)), (2 + (max_words * 2.2))),
                                panel_grid_major = element_line(color='black',size = 0.1),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
@@ -404,19 +406,20 @@ def cappuccino(text: str,                  # Text
                        + geom_tile(aes(width=.95, height=.95))
                        + geom_text(aes(label='frequency'), size=10)
                        + theme_minimal()
-                       + scale_fill_gradient(name = "frequency",
-                                             low = "#f0f4ed",
-                                             high = "#496160")
                        + theme(axis_title_x=element_text(colour = "black"),
                                axis_title_y=element_text(colour="black"),
-                               axis_text_x=element_text(colour = "black", rotation=45, hjust=1),
-                               figure_size=(10, 8),
+                               axis_text_x=element_text(colour = "black", rotation=45, hjust= 1),
+                               legend_text = element_text(size = 5,vjust = 0.2),
+                               legend_title = element_text(color = "black", vjust = 0.8, size = 10),
+                               figure_size= (3 + ((len(period) /4)), (2 + (max_words * 1.7))),
                                panel_grid_major = element_line(color='black',size = 0.1),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
+                       + scale_fill_gradient(name = "frequency",
+                                             low = "#f0f4ed",
+                                             high = "#496160")
                        ).draw(show=False, return_ggplot=True)
 
-
                 plt.gcf().set_dpi(800)
                 picture = plt.show()
 
@@ -449,7 +452,7 @@ def cappuccino(text: str,                  # Text
                                legend_title = element_text(size=10),
                                legend_key_height = 0.5,
                                legend_key_width = 0.5,
-                               figure_size=(10, 5),
+                               figure_size=(5 + max_words, (1 + (max_words * 1.0))),
                                panel_grid_major = element_blank(),
                                panel_background = element_rect(colour = "white", fill = "white"),
                                plot_background = element_rect(colour = 'white',fill = "white"))
@@ -495,4 +498,5 @@ def cappuccino(text: str,                  # Text
     else:
         sys.exit("Incorrect value for ngram parameter. Allowed: 1,2,3.")
 
-    return picture
\ No newline at end of file
+    return picture
+#%%
